@@ -1,18 +1,18 @@
-pub mod names;
-pub mod json_obj_to_rust;
-pub mod json_name;
-pub mod tmp;
-pub mod json_item_to_rust;
-pub mod json_array_to_rust;
-pub mod array_null;
-pub mod list;
-pub mod get_old;
-pub mod get_id;
-pub mod get_refs;
-pub mod construct_root;
-pub mod validation;
-pub mod set_empty_mils;
-pub mod roots;
+pub(crate) mod names;
+pub(crate) mod json_obj_to_rust;
+pub(crate) mod json_name;
+pub(crate) mod tmp;
+pub(crate) mod json_item_to_rust;
+pub(crate) mod json_array_to_rust;
+pub(crate) mod array_null;
+pub(crate) mod list;
+pub(crate) mod get_old;
+pub(crate) mod get_id;
+pub(crate) mod get_refs;
+pub(crate) mod construct_root;
+pub(crate) mod validation;
+pub(crate) mod set_empty_mils;
+pub(crate) mod roots;
 
 use docchi_json5::JVal;
 use names::Names;
